@@ -2,12 +2,18 @@
 Functions for getting data from variables.
 
 Copyright 2011 University Corporation for Atmospheric
-Research/Unidata. See \ref COPYRIGHT file for more info. */
+Research/Unidata. See \ref copyright file for more info.
+
+*/
 
 #include "ncdispatch.h"
 
 #undef VARS_USES_VARM
 #ifndef VARS_USES_VARM
+
+/*! \internal
+
+ */
 struct GETodometer {
     int            rank;
     size_t         index[NC_MAX_VAR_DIMS];
@@ -17,9 +23,13 @@ struct GETodometer {
     size_t         stop[NC_MAX_VAR_DIMS];
 };
 
+
+/** \internal
+
+ */
 static void
 odom_init(struct GETodometer* odom,
-	    size_t rank,
+	    int rank,
 	    const size_t* start, const size_t* edges, const ptrdiff_t* stride)
 {
     int i;
@@ -30,24 +40,30 @@ odom_init(struct GETodometer* odom,
 	odom->start[i] = (start != NULL ? start[i] : 0);
 	odom->edges[i] = (edges != NULL ? edges[i] : 1);
 	odom->stride[i] = (stride != NULL ? stride[i] : 1);
-	odom->stop[i] = odom->start[i] + (odom->edges[i]*odom->stride[i]);
+	odom->stop[i] = odom->start[i] + (odom->edges[i]*((size_t)odom->stride[i]));
 	odom->index[i] = odom->start[i];
-    }    
+    }
 }
 
+/** \internal
+
+ */
 static int
 odom_more(struct GETodometer* odom)
 {
     return (odom->index[0] < odom->stop[0]);
 }
 
+/** \internal
+
+ */
 static int
 odom_next(struct GETodometer* odom)
 {
     int i;
     if(odom->rank == 0) return 0;
     for(i=odom->rank-1;i>=0;i--) {
-        odom->index[i] += odom->stride[i];
+        odom->index[i] += (size_t)odom->stride[i];
         if(odom->index[i] < odom->stop[i]) break;
 	if(i == 0) return 0; /* leave the 0th entry if it overflows*/
 	odom->index[i] = odom->start[i]; /* reset this position*/
@@ -57,7 +73,7 @@ odom_next(struct GETodometer* odom)
 #endif
 
 /** \internal
-\ingroup variables 
+\ingroup variables
 
  */
 int
@@ -71,19 +87,21 @@ NC_get_vara(int ncid, int varid,
 #ifdef USE_NETCDF4
    if(memtype >= NC_FIRSTUSERTYPEID) memtype = NC_NAT;
 #endif
+
    if(edges == NULL) {
       size_t shape[NC_MAX_VAR_DIMS];
       int ndims;
-      stat = nc_inq_varndims(ncid, varid, &ndims); 
+      stat = nc_inq_varndims(ncid, varid, &ndims);
       if(stat != NC_NOERR) return stat;
       stat = NC_getshape(ncid,varid,ndims,shape);
       if(stat != NC_NOERR) return stat;
-      return ncp->dispatch->get_vara(ncid,varid,start,shape,value,memtype);
+      stat = ncp->dispatch->get_vara(ncid,varid,start,shape,value,memtype);
    } else
-      return ncp->dispatch->get_vara(ncid,varid,start,edges,value,memtype);
+      stat =  ncp->dispatch->get_vara(ncid,varid,start,edges,value,memtype);
+   return stat;
 }
 
-/** \ingroup variables 
+/** \ingroup variables
 \internal
  */
 static int
@@ -99,7 +117,7 @@ NC_get_var(int ncid, int varid, void *value, nc_type memtype)
 }
 
 /** \internal
-\ingroup variables 
+\ingroup variables
  Most dispatch tables will use the default procedures
 */
 int
@@ -115,13 +133,15 @@ NCDEFAULT_get_vars(int ncid, int varid, const size_t * start,
    return ncp->dispatch->get_varm(ncid,varid,start,edges,stride,NULL,value0,memtype);
 #else
   /* Rebuilt get_vars code to simplify and avoid use of get_varm */
-  
+
    int status = NC_NOERR;
-   int i,simplestride,rank,isrecvar;
+   int i,simplestride,isrecvar;
+   int rank;
    struct GETodometer odom;
    nc_type vartype = NC_NAT;
    NC* ncp;
-   size_t vartypelen, memtypelen;
+   int memtypelen;
+   size_t vartypelen;
    char* value = (char*)value0;
    size_t numrecs;
    size_t varshape[NC_MAX_VAR_DIMS];
@@ -133,7 +153,7 @@ NCDEFAULT_get_vars(int ncid, int varid, const size_t * start,
    status = NC_check_id (ncid, &ncp);
    if(status != NC_NOERR) return status;
 
-   status = nc_inq_vartype(ncid, varid, &vartype); 
+   status = nc_inq_vartype(ncid, varid, &vartype);
    if(status != NC_NOERR) return status;
 
    if(memtype == NC_NAT) memtype = vartype;
@@ -143,7 +163,7 @@ NCDEFAULT_get_vars(int ncid, int varid, const size_t * start,
    if(status != NC_NOERR) return status;
 
    if(memtype > NC_MAX_ATOMIC_TYPE)
-	memtypelen = vartypelen;
+	memtypelen = (int)vartypelen;
     else
 	memtypelen = nctypelen(memtype);
 
@@ -159,12 +179,12 @@ NCDEFAULT_get_vars(int ncid, int varid, const size_t * start,
    }
 
    /* Get the variable rank */
-   status = nc_inq_varndims(ncid, varid, &rank); 
+   status = nc_inq_varndims(ncid, varid, &rank);
    if(status != NC_NOERR) return status;
 
    /* Get variable dimension sizes */
    isrecvar = NC_is_recvar(ncid,varid,&numrecs);
-   NC_getshape(ncid,varid,rank,varshape);	
+   NC_getshape(ncid,varid,rank,varshape);
 
    /* Optimize out using various checks */
    if (rank == 0) {
@@ -196,13 +216,15 @@ NCDEFAULT_get_vars(int ncid, int varid, const size_t * start,
 	   /* cast needed for braindead systems with signed size_t */
            || ((unsigned long) mystride[i] >= X_INT_MAX))
            return NC_ESTRIDE;
-  	if(mystride[i] != 1) simplestride = 0;	
+  	if(mystride[i] != 1) simplestride = 0;
         /* illegal value checks */
 	dimlen = (i == 0 && isrecvar ? numrecs : varshape[i]);
-        if(mystart < 0 || mystart[i] >= dimlen)
-	   return NC_EINVALCOORDS;
-        if(myedges[i] < 0 || (mystart[i] + myedges[i] > dimlen))
-	   return NC_EEDGE;
+        /* mystart is unsigned, never < 0 */
+	if(mystart[i] >= dimlen)
+	  return NC_EINVALCOORDS;
+        /* myedges is unsigned, never < 0 */
+	if(mystart[i] + myedges[i] > dimlen)
+	  return NC_EEDGE;
    }
    if(simplestride) {
       return NC_get_vara(ncid, varid, mystart, myedges, value, memtype);
@@ -233,17 +255,17 @@ NCDEFAULT_get_vars(int ncid, int varid, const size_t * start,
 }
 
 /** \internal
-\ingroup variables 
+\ingroup variables
  */
 static int
-NC_get_var1(int ncid, int varid, const size_t *coord, void* value, 
+NC_get_var1(int ncid, int varid, const size_t *coord, void* value,
 	    nc_type memtype)
 {
    return NC_get_vara(ncid, varid, coord, NC_coord_one, value, memtype);
 }
 
 /** \internal
-\ingroup variables 
+\ingroup variables
  */
 int
 NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
@@ -254,7 +276,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
    nc_type vartype = NC_NAT;
    int varndims,maxidim;
    NC* ncp;
-   size_t memtypelen;
+   int memtypelen;
    ptrdiff_t cvtmap[NC_MAX_VAR_DIMS];
    char* value = (char*)value0;
 
@@ -265,13 +287,13 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
   if(NC_indef(ncp)) return NC_EINDEFINE;
 */
 
-   status = nc_inq_vartype(ncid, varid, &vartype); 
+   status = nc_inq_vartype(ncid, varid, &vartype);
    if(status != NC_NOERR) return status;
    /* Check that this is an atomic type */
    if(vartype > NC_MAX_ATOMIC_TYPE)
 	return NC_EMAPTYPE;
 
-   status = nc_inq_varndims(ncid, varid, &varndims); 
+   status = nc_inq_varndims(ncid, varid, &varndims);
    if(status != NC_NOERR) return status;
 
    if(memtype == NC_NAT) {
@@ -295,7 +317,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 
    if(memtype == NC_CHAR && vartype != NC_CHAR)
       return NC_ECHAR;
-   else if(memtype != NC_CHAR && vartype == NC_CHAR)  
+   else if(memtype != NC_CHAR && vartype == NC_CHAR)
       return NC_ECHAR;
 
    memtypelen = nctypelen(memtype);
@@ -332,7 +354,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 
       /* Compute some dimension related values */
       isrecvar = NC_is_recvar(ncid,varid,&numrecs);
-      NC_getshape(ncid,varid,varndims,varshape);	
+      NC_getshape(ncid,varid,varndims,varshape);
 
       /*
        * Verify stride argument; also see if stride is all ones
@@ -349,7 +371,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
             }
 	    if(stride[idim] != 1) stride1 = 0;
 	 }
-         /* If stride1 is true, and there is no imap 
+         /* If stride1 is true, and there is no imap
             then call get_vara directly.
          */
          if(stride1 && imapp == NULL) {
@@ -359,7 +381,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 
       /* assert(sizeof(ptrdiff_t) >= sizeof(size_t)); */
       /* Allocate space for mystart,mystride,mymap etc.all at once */
-      mystart = (size_t *)calloc(varndims * 7, sizeof(ptrdiff_t));
+      mystart = (size_t *)calloc((size_t)(varndims * 7), sizeof(ptrdiff_t));
       if(mystart == NULL) return NC_ENOMEM;
       myedges = mystart + varndims;
       iocount = myedges + varndims;
@@ -414,12 +436,12 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 	 else if (idim == maxidim)
 	    mymap[idim] = 1;
 	 else
-	    mymap[idim] = 
+	    mymap[idim] =
 	       mymap[idim + 1] * (ptrdiff_t) myedges[idim + 1];
 #endif
 	 iocount[idim] = 1;
-	 length[idim] = mymap[idim] * myedges[idim];
-	 stop[idim] = mystart[idim] + myedges[idim] * mystride[idim];
+	 length[idim] = ((size_t)mymap[idim]) * myedges[idim];
+	 stop[idim] = (mystart[idim] + myedges[idim] * (size_t)mystride[idim]);
       }
 
       /*
@@ -427,7 +449,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
        */
       for (idim = maxidim; idim >= 0; --idim)
       {
-	 size_t dimlen = 
+	 size_t dimlen =
 	    idim == 0 && isrecvar
 	    ? numrecs
 	    : varshape[idim];
@@ -448,7 +470,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 
       /* Lower body */
       /*
-       * As an optimization, adjust I/O parameters when the fastest 
+       * As an optimization, adjust I/O parameters when the fastest
        * dimension has unity stride both externally and internally.
        * In this case, the user could have called a simpler routine
        * (i.e. ncvar$1()
@@ -461,7 +483,7 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 	 mymap[maxidim] = (ptrdiff_t) length[maxidim];
       }
 
-      /* 
+      /*
        * Perform I/O.  Exit when done.
        */
       for (;;)
@@ -481,12 +503,13 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
 	  */
 	 idim = maxidim;
         carry:
-	 value += (mymap[idim] * memtypelen);
-	 mystart[idim] += mystride[idim];
+	 value += (((int)mymap[idim]) * memtypelen);
+	 mystart[idim] += (size_t)mystride[idim];
 	 if (mystart[idim] == stop[idim])
 	 {
+	    size_t l = (length[idim] * (size_t)memtypelen);
+	    value -= l;
 	    mystart[idim] = start[idim];
-	    value -= (length[idim] * memtypelen);
 	    if (--idim < 0)
 	       break; /* normal return */
 	    goto carry;
@@ -498,11 +521,11 @@ NCDEFAULT_get_varm(int ncid, int varid, const size_t *start,
    return status;
 }
 
-/** \ingroup variables 
+/** \ingroup variables
 \internal
 Called by externally visible nc_get_vars_xxx routines */
 static int
-NC_get_vars(int ncid, int varid, const size_t *start, 
+NC_get_vars(int ncid, int varid, const size_t *start,
 	    const size_t *edges, const ptrdiff_t *stride, void *value,
 	    nc_type memtype)
 {
@@ -516,12 +539,12 @@ NC_get_vars(int ncid, int varid, const size_t *start,
    return ncp->dispatch->get_vars(ncid,varid,start,edges,stride,value,memtype);
 }
 
-/** \ingroup variables 
+/** \ingroup variables
 \internal
-Called by externally visible nc_get_varm_xxx routines 
+Called by externally visible nc_get_varm_xxx routines
  */
 static int
-NC_get_varm(int ncid, int varid, const size_t *start, 
+NC_get_varm(int ncid, int varid, const size_t *start,
 	    const size_t *edges, const ptrdiff_t *stride, const ptrdiff_t* map,
 	    void *value, nc_type memtype)
 {
@@ -541,10 +564,10 @@ Functions to read data from variables. */
 /*! \{ */ /* All these functions are part of this named group... */
 
 /** \ingroup variables
-Read an array of values from a variable. 
+Read an array of values from a variable.
 
 The array to be read is specified by giving a corner and a vector of
-edge lengths to \ref specify_hyperslab. 
+edge lengths to \ref specify_hyperslab.
 
 The data values are read into consecutive locations with the last
 dimension varying fastest. The netCDF dataset must be in data mode
@@ -560,7 +583,7 @@ Other nc_get_vara_ functions will convert data to the desired output
 type as needed.
 
 \param ncid NetCDF or group ID, from a previous call to nc_open(),
-nc_create(), nc_def_grp(), or associated inquiry functions such as 
+nc_create(), nc_def_grp(), or associated inquiry functions such as
 nc_inq_ncid().
 
 \param varid Variable ID
@@ -582,7 +605,7 @@ allocated by the user before this function is called.
 \returns ::NC_EINDEFINE Operation not allowed in define mode.
 \returns ::NC_EBADID Bad ncid.
 
-\section Example
+\section nc_get_vara_double_example Example
 
 Here is an example using nc_get_vara_double() to read all the values of
 the variable named rh from an existing netCDF dataset named
@@ -596,12 +619,12 @@ values, five lat values, and ten lon values.
      #define TIMES 3
      #define LATS 5
      #define LONS 10
-     int  status;                      
-     int ncid;                         
-     int rh_id;                        
+     int  status;
+     int ncid;
+     int rh_id;
      static size_t start[] = {0, 0, 0};
      static size_t count[] = {TIMES, LATS, LONS};
-     double rh_vals[TIMES*LATS*LONS]; 
+     double rh_vals[TIMES*LATS*LONS];
         ...
      status = nc_open("foo.nc", NC_NOWRITE, &ncid);
      if (status != NC_NOERR) handle_error(status);
@@ -615,7 +638,7 @@ values, five lat values, and ten lon values.
  */
 /**@{*/
 int
-nc_get_vara(int ncid, int varid, const size_t *startp, 
+nc_get_vara(int ncid, int varid, const size_t *startp,
 	    const size_t *countp, void *ip)
 {
    NC* ncp = NULL;
@@ -628,46 +651,46 @@ nc_get_vara(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vara_text(int ncid, int varid, const size_t *startp, 
+nc_get_vara_text(int ncid, int varid, const size_t *startp,
 		 const size_t *countp, char *ip)
 {
    NC* ncp;
    int stat = NC_check_id(ncid, &ncp);
    if(stat != NC_NOERR) return stat;
-   return NC_get_vara(ncid, varid, startp, countp, 
+   return NC_get_vara(ncid, varid, startp, countp,
 		      (void *)ip, NC_CHAR);
 }
 
 int
-nc_get_vara_schar(int ncid, int varid, const size_t *startp, 
+nc_get_vara_schar(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, signed char *ip)
 {
    NC* ncp;
    int stat = NC_check_id(ncid, &ncp);
    if(stat != NC_NOERR) return stat;
-   return NC_get_vara(ncid, varid, startp, countp, 
+   return NC_get_vara(ncid, varid, startp, countp,
 		      (void *)ip, NC_BYTE);
 }
 
 int
-nc_get_vara_uchar(int ncid, int varid, const size_t *startp, 
+nc_get_vara_uchar(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, unsigned char *ip)
 {
    NC* ncp;
    int stat = NC_check_id(ncid, &ncp);
    if(stat != NC_NOERR) return stat;
-   return NC_get_vara(ncid, varid, startp, countp, 
+   return NC_get_vara(ncid, varid, startp, countp,
 		      (void *)ip, T_uchar);
 }
 
 int
-nc_get_vara_short(int ncid, int varid, const size_t *startp, 
+nc_get_vara_short(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, short *ip)
 {
    NC* ncp;
    int stat = NC_check_id(ncid, &ncp);
    if(stat != NC_NOERR) return stat;
-   return NC_get_vara(ncid, varid, startp, countp, 
+   return NC_get_vara(ncid, varid, startp, countp,
 		      (void *)ip, NC_SHORT);
 }
 
@@ -703,7 +726,7 @@ nc_get_vara_float(int ncid, int varid,
 
 
 int
-nc_get_vara_double(int ncid, int varid, const size_t *startp, 
+nc_get_vara_double(int ncid, int varid, const size_t *startp,
 		   const size_t *countp, double *ip)
 {
    NC* ncp;
@@ -777,7 +800,7 @@ nc_get_vara_string(int ncid, int varid,
 /**@}*/
 
 /** \ingroup variables
-Read a single datum from a variable. 
+Read a single datum from a variable.
 
 Inputs are the netCDF ID, the variable ID, a multidimensional index
 that specifies which value to get, and the address of a location into
@@ -792,7 +815,7 @@ Other nc_get_var1_ functions will convert data to the desired output
 type as needed.
 
 \param ncid NetCDF or group ID, from a previous call to nc_open(),
-nc_create(), nc_def_grp(), or associated inquiry functions such as 
+nc_create(), nc_def_grp(), or associated inquiry functions such as
 nc_inq_ncid().
 
 \param varid Variable ID
@@ -862,7 +885,7 @@ nc_get_var1_int(int ncid, int varid, const size_t *indexp, int *ip)
 }
 
 int
-nc_get_var1_long(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_long(int ncid, int varid, const size_t *indexp,
 		 long *ip)
 {
    NC* ncp;
@@ -872,7 +895,7 @@ nc_get_var1_long(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_float(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_float(int ncid, int varid, const size_t *indexp,
 		  float *ip)
 {
    NC* ncp;
@@ -882,7 +905,7 @@ nc_get_var1_float(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_double(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_double(int ncid, int varid, const size_t *indexp,
 		   double *ip)
 {
    NC* ncp;
@@ -892,7 +915,7 @@ nc_get_var1_double(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_ubyte(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_ubyte(int ncid, int varid, const size_t *indexp,
 		  unsigned char *ip)
 {
    NC* ncp;
@@ -902,7 +925,7 @@ nc_get_var1_ubyte(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_ushort(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_ushort(int ncid, int varid, const size_t *indexp,
 		   unsigned short *ip)
 {
    NC* ncp;
@@ -912,7 +935,7 @@ nc_get_var1_ushort(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_uint(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_uint(int ncid, int varid, const size_t *indexp,
 		 unsigned int *ip)
 {
    NC* ncp;
@@ -922,7 +945,7 @@ nc_get_var1_uint(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_longlong(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_longlong(int ncid, int varid, const size_t *indexp,
 		     long long *ip)
 {
    NC* ncp;
@@ -932,7 +955,7 @@ nc_get_var1_longlong(int ncid, int varid, const size_t *indexp,
 }
 
 int
-nc_get_var1_ulonglong(int ncid, int varid, const size_t *indexp, 
+nc_get_var1_ulonglong(int ncid, int varid, const size_t *indexp,
 		      unsigned long long *ip)
 {
    NC* ncp;
@@ -954,7 +977,7 @@ nc_get_var1_string(int ncid, int varid, const size_t *indexp, char* *ip)
 /** \} */
 
 /** \ingroup variables
-Read an entire variable in one call. 
+Read an entire variable in one call.
 
 This function will read all the values from a netCDF variable of an
 open netCDF dataset.
@@ -981,7 +1004,7 @@ user defined type. For this function, the type of the data in memory
 must match the type of the variable - no data conversion is done.
 
 \param ncid NetCDF or group ID, from a previous call to nc_open(),
-nc_create(), nc_def_grp(), or associated inquiry functions such as 
+nc_create(), nc_def_grp(), or associated inquiry functions such as
 nc_inq_ncid().
 
 \param varid Variable ID
@@ -1132,7 +1155,7 @@ nc_get_var_string(int ncid, int varid, char* *ip)
 /** \} */
 
 /** \ingroup variables
-Read a strided array from a variable. 
+Read a strided array from a variable.
 
 This function reads a subsampled (strided) array section of values
 from a netCDF variable of an open netCDF dataset. The subsampled array
@@ -1146,7 +1169,7 @@ user defined type. For this function, the type of the data in memory
 must match the type of the variable - no data conversion is done.
 
 \param ncid NetCDF or group ID, from a previous call to nc_open(),
-nc_create(), nc_def_grp(), or associated inquiry functions such as 
+nc_create(), nc_def_grp(), or associated inquiry functions such as
 nc_inq_ncid().
 
 \param varid Variable ID
@@ -1186,7 +1209,7 @@ nc_get_vars (int ncid, int varid, const size_t * startp,
 }
 
 int
-nc_get_vars_text(int ncid, int varid, const size_t *startp, 
+nc_get_vars_text(int ncid, int varid, const size_t *startp,
 		 const size_t *countp, const ptrdiff_t * stridep,
 		 char *ip)
 {
@@ -1198,7 +1221,7 @@ nc_get_vars_text(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_schar(int ncid, int varid, const size_t *startp, 
+nc_get_vars_schar(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, const ptrdiff_t * stridep,
 		  signed char *ip)
 {
@@ -1210,7 +1233,7 @@ nc_get_vars_schar(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_uchar(int ncid, int varid, const size_t *startp, 
+nc_get_vars_uchar(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, const ptrdiff_t * stridep,
 		  unsigned char *ip)
 {
@@ -1222,19 +1245,19 @@ nc_get_vars_uchar(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_short(int ncid, int varid, const size_t *startp, 
+nc_get_vars_short(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, const ptrdiff_t *stridep,
 		  short *ip)
 {
    NC* ncp;
    int stat = NC_check_id(ncid, &ncp);
    if(stat != NC_NOERR) return stat;
-   return NC_get_vars(ncid,varid,startp, countp, stridep, 
+   return NC_get_vars(ncid,varid,startp, countp, stridep,
 		      (void *)ip, NC_SHORT);
 }
 
 int
-nc_get_vars_int(int ncid, int varid, const size_t *startp, 
+nc_get_vars_int(int ncid, int varid, const size_t *startp,
 		const size_t *countp, const ptrdiff_t * stridep,
 		int *ip)
 {
@@ -1246,7 +1269,7 @@ nc_get_vars_int(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_long(int ncid, int varid, const size_t *startp, 
+nc_get_vars_long(int ncid, int varid, const size_t *startp,
 		 const size_t *countp, const ptrdiff_t * stridep,
 		 long *ip)
 {
@@ -1258,7 +1281,7 @@ nc_get_vars_long(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_float(int ncid, int varid, const size_t *startp, 
+nc_get_vars_float(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, const ptrdiff_t * stridep,
 		  float *ip)
 {
@@ -1270,7 +1293,7 @@ nc_get_vars_float(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_double(int ncid, int varid, const size_t *startp, 
+nc_get_vars_double(int ncid, int varid, const size_t *startp,
 		   const size_t *countp, const ptrdiff_t * stridep,
 		   double *ip)
 {
@@ -1282,7 +1305,7 @@ nc_get_vars_double(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_ubyte(int ncid, int varid, const size_t *startp, 
+nc_get_vars_ubyte(int ncid, int varid, const size_t *startp,
 		  const size_t *countp, const ptrdiff_t * stridep,
 		  unsigned char *ip)
 {
@@ -1294,7 +1317,7 @@ nc_get_vars_ubyte(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_ushort(int ncid, int varid, const size_t *startp, 
+nc_get_vars_ushort(int ncid, int varid, const size_t *startp,
 		   const size_t *countp, const ptrdiff_t * stridep,
 		   unsigned short *ip)
 {
@@ -1306,7 +1329,7 @@ nc_get_vars_ushort(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_uint(int ncid, int varid, const size_t *startp, 
+nc_get_vars_uint(int ncid, int varid, const size_t *startp,
 		 const size_t *countp, const ptrdiff_t * stridep,
 		 unsigned int *ip)
 {
@@ -1318,7 +1341,7 @@ nc_get_vars_uint(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_longlong(int ncid, int varid, const size_t *startp, 
+nc_get_vars_longlong(int ncid, int varid, const size_t *startp,
 		     const size_t *countp, const ptrdiff_t * stridep,
 		     long long *ip)
 {
@@ -1330,7 +1353,7 @@ nc_get_vars_longlong(int ncid, int varid, const size_t *startp,
 }
 
 int
-nc_get_vars_ulonglong(int ncid, int varid, const size_t *startp, 
+nc_get_vars_ulonglong(int ncid, int varid, const size_t *startp,
 		      const size_t *countp, const ptrdiff_t * stridep,
 		      unsigned long long *ip)
 {
@@ -1351,14 +1374,14 @@ nc_get_vars_string(int ncid, int varid,
    NC* ncp;
    int stat = NC_check_id(ncid, &ncp);
    if(stat != NC_NOERR) return stat;
-   return NC_get_vars(ncid, varid, startp, countp, stridep, 
+   return NC_get_vars(ncid, varid, startp, countp, stridep,
 		      (void *)ip, NC_STRING);
 }
 #endif /*USE_NETCDF4*/
 /** \} */
 
 /** \ingroup variables
-Read a mapped array from a variable. 
+Read a mapped array from a variable.
 
 The nc_get_varm_ type family of functions reads a mapped array section
 of values from a netCDF variable of an open netCDF dataset. The mapped
@@ -1378,12 +1401,13 @@ atomic type; it will not read user defined types. For this
 function, the type of the data in memory must match the type
 of the variable - no data conversion is done.
 
-Use of this family of functions is discouraged, although not
-formally deprecated. The reason is the complexity of the
+@deprecated Use of this family of functions is discouraged,
+although it will continue to be supported.
+The reason is the complexity of the
 algorithm makes its use difficult for users to properly use.
 
 \param ncid NetCDF or group ID, from a previous call to nc_open(),
-nc_create(), nc_def_grp(), or associated inquiry functions such as 
+nc_create(), nc_def_grp(), or associated inquiry functions such as
 nc_inq_ncid().
 
 \param varid Variable ID
@@ -1421,14 +1445,14 @@ nc_get_varm(int ncid, int varid, const size_t * startp,
 
    if ((stat = NC_check_id(ncid, &ncp)))
        return stat;
-   return ncp->dispatch->get_varm(ncid, varid, startp, countp, 
+   return ncp->dispatch->get_varm(ncid, varid, startp, countp,
 				  stridep, imapp, ip, NC_NAT);
 }
 
 int
 nc_get_varm_schar(int ncid, int varid,
 		  const size_t *startp, const size_t *countp,
-		  const ptrdiff_t *stridep, 
+		  const ptrdiff_t *stridep,
 		  const ptrdiff_t *imapp, signed char *ip)
 {
    NC *ncp;
@@ -1451,8 +1475,8 @@ nc_get_varm_uchar(int ncid, int varid,
 }
 
 int
-nc_get_varm_short(int ncid, int varid, const size_t *startp, 
-		  const size_t *countp, const ptrdiff_t *stridep, 
+nc_get_varm_short(int ncid, int varid, const size_t *startp,
+		  const size_t *countp, const ptrdiff_t *stridep,
 		  const ptrdiff_t *imapp, short *ip)
 {
    NC *ncp;
@@ -1549,8 +1573,8 @@ nc_get_varm_uint(int ncid, int varid,
 }
 
 int
-nc_get_varm_longlong(int ncid, int varid, const size_t *startp, 
-		     const size_t *countp, const ptrdiff_t *stridep, 
+nc_get_varm_longlong(int ncid, int varid, const size_t *startp,
+		     const size_t *countp, const ptrdiff_t *stridep,
 		     const ptrdiff_t *imapp, long long *ip)
 {
    NC *ncp;
@@ -1574,8 +1598,8 @@ nc_get_varm_ulonglong(int ncid, int varid,
 }
 
 int
-nc_get_varm_text(int ncid, int varid, const size_t *startp, 
-		 const size_t *countp, const ptrdiff_t *stridep, 
+nc_get_varm_text(int ncid, int varid, const size_t *startp,
+		 const size_t *countp, const ptrdiff_t *stridep,
 		 const ptrdiff_t *imapp, char *ip)
 {
    NC *ncp;
@@ -1587,8 +1611,8 @@ nc_get_varm_text(int ncid, int varid, const size_t *startp,
 
 #ifdef USE_NETCDF4
 int
-nc_get_varm_string(int ncid, int varid, const size_t *startp, 
-		   const size_t *countp, const ptrdiff_t *stridep, 
+nc_get_varm_string(int ncid, int varid, const size_t *startp,
+		   const size_t *countp, const ptrdiff_t *stridep,
 		   const ptrdiff_t *imapp, char **ip)
 {
    NC *ncp;
@@ -1602,4 +1626,3 @@ nc_get_varm_string(int ncid, int varid, const size_t *startp,
 
 
 /*! \} */ /* End of named group... */
-
